@@ -693,10 +693,6 @@ class LBM_Regression:
     
     def transform(self, X, y=None, scaler: str ='robust', variable_instant:bool=True, allow_autointeraction=False, 
                   interaction_list: list = None):
-        #   ['X_xor_Y', 'X_or_Y', 'X_or_not_Y', 
-        #                     'X_and_Y','X_and_not_Y', 'X_if_Y', 'X_if_not_Y', 
-        #                     'X_if_Y_average', 'X_average_if_Y', 'Neither_X_nor_Y_extreme', 'both_X_Y_average', 
-        #                    ' X_like_Y', 'Sum_X_Y', 'Difference_X_Y']):
         """
         transform method :
         
@@ -712,7 +708,7 @@ class LBM_Regression:
             self
         
         """
-        if not interaction_list:
+        if interaction_list is None:
             interaction_list = Interaction.get_interaction_list()
             print(interaction_list)
 
@@ -783,7 +779,7 @@ class LBM_Regression:
         #Mesure du temps de calcul
         start = time.time()
         
-        if not X:
+        if X is None:
           X= self.rescaled_features
         
         if type(threshold) is not float:
